@@ -1,7 +1,8 @@
 from typing import Any, cast, Union
 
-from gitlab.base import RequiredOptional, RESTManager, RESTObject
+from gitlab.base import RESTManager, RESTObject
 from gitlab.mixins import NoUpdateMixin, ObjectDeleteMixin
+from gitlab.types import RequiredOptional
 
 __all__ = [
     "ProjectBranch",
