@@ -89,6 +89,16 @@ def release(project, tag_name):
     return project.releases.get(tag_name, lazy=True)
 
 
+@pytest.fixture
+def schedule(project):
+    return project.pipelineschedules.get(1, lazy=True)
+
+
 @pytest.fixture
 def user(gl):
     return gl.users.get(1, lazy=True)
+
+
+@pytest.fixture
+def migration(gl):
+    return gl.bulk_imports.get(1, lazy=True)
