@@ -80,6 +80,58 @@ def resp_activate():
         yield rsps
 
 
+@pytest.fixture
+def resp_approve():
+    with responses.RequestsMock() as rsps:
+        rsps.add(
+            method=responses.POST,
+            url="http://localhost/api/v4/users/1/approve",
+            json={"message": "Success"},
+            content_type="application/json",
+            status=201,
+        )
+        yield rsps
+
+
+@pytest.fixture
+def resp_reject():
+    with responses.RequestsMock() as rsps:
+        rsps.add(
+            method=responses.POST,
+            url="http://localhost/api/v4/users/1/reject",
+            json={"message": "Success"},
+            content_type="application/json",
+            status=201,
+        )
+        yield rsps
+
+
+@pytest.fixture
+def resp_ban():
+    with responses.RequestsMock() as rsps:
+        rsps.add(
+            method=responses.POST,
+            url="http://localhost/api/v4/users/1/ban",
+            json={},
+            content_type="application/json",
+            status=201,
+        )
+        yield rsps
+
+
+@pytest.fixture
+def resp_unban():
+    with responses.RequestsMock() as rsps:
+        rsps.add(
+            method=responses.POST,
+            url="http://localhost/api/v4/users/1/unban",
+            json={},
+            content_type="application/json",
+            status=201,
+        )
+        yield rsps
+
+
 @pytest.fixture
 def resp_get_user_status():
     content = {
@@ -216,6 +268,22 @@ def test_user_activate_deactivate(user, resp_activate):
     user.deactivate()
 
 
+def test_user_approve_(user, resp_approve):
+    user.approve()
+
+
+def test_user_approve_reject(user, resp_reject):
+    user.reject()
+
+
+def test_user_ban(user, resp_ban):
+    user.ban()
+
+
+def test_user_unban(user, resp_unban):
+    user.unban()
+
+
 def test_delete_user_identity(user, resp_delete_user_identity):
     user.identityproviders.delete("test_provider")
 
