@@ -6,7 +6,7 @@ import requests
 import responses
 
 from gitlab import GitlabHttpError, GitlabList, GitlabParsingError, RedirectError
-from gitlab.client import RETRYABLE_TRANSIENT_ERROR_CODES
+from gitlab.const import RETRYABLE_TRANSIENT_ERROR_CODES
 from tests.unit import helpers
 
 
@@ -372,6 +372,63 @@ def test_http_request_302_put_raises_redirect_error(gl):
     assert "http://example.com/api/v4/user/status" in error_message
 
 
+def test_http_request_on_409_resource_lock_retries(gl_retry):
+    url = "http://localhost/api/v4/user"
+    retried = False
+
+    def response_callback(
+        response: requests.models.Response,
+    ) -> requests.models.Response:
+        """We need a callback that adds a resource lock reason only on first call"""
+        nonlocal retried
+
+        if not retried:
+            response.reason = "Resource lock"
+
+        retried = True
+        return response
+
+    with responses.RequestsMock(response_callback=response_callback) as rsps:
+        rsps.add(
+            method=responses.GET,
+            url=url,
+            status=409,
+            match=helpers.MATCH_EMPTY_QUERY_PARAMS,
+        )
+        rsps.add(
+            method=responses.GET,
+            url=url,
+            status=200,
+            match=helpers.MATCH_EMPTY_QUERY_PARAMS,
+        )
+        response = gl_retry.http_request("get", "/user")
+
+    assert response.status_code == 200
+
+
+def test_http_request_on_409_resource_lock_without_retry_raises(gl):
+    url = "http://localhost/api/v4/user"
+
+    def response_callback(
+        response: requests.models.Response,
+    ) -> requests.models.Response:
+        """Without retry, this will fail on the first call"""
+        response.reason = "Resource lock"
+        return response
+
+    with responses.RequestsMock(response_callback=response_callback) as req_mock:
+        req_mock.add(
+            method=responses.GET,
+            url=url,
+            status=409,
+            match=helpers.MATCH_EMPTY_QUERY_PARAMS,
+        )
+        with pytest.raises(GitlabHttpError) as excinfo:
+            gl.http_request("get", "/user")
+
+    assert excinfo.value.response_code == 409
+
+
 @responses.activate
 def test_get_request(gl):
     url = "http://localhost/api/v4/projects"
@@ -485,6 +542,29 @@ def test_list_request(gl):
     assert responses.assert_call_count(url, 3) is True
 
 
+@responses.activate
+def test_list_request_page_and_iterator(gl):
+    response_dict = copy.deepcopy(large_list_response)
+    response_dict["match"] = [responses.matchers.query_param_matcher({"page": "1"})]
+    responses.add(**response_dict)
+
+    with pytest.warns(
+        UserWarning, match="`iterator=True` and `page=1` were both specified"
+    ):
+        result = gl.http_list("/projects", iterator=True, page=1)
+    assert isinstance(result, list)
+    assert len(result) == 20
+    assert len(responses.calls) == 1
+
+    with pytest.warns(
+        UserWarning, match="`as_list=False` and `page=1` were both specified"
+    ):
+        result = gl.http_list("/projects", as_list=False, page=1)
+    assert isinstance(result, list)
+    assert len(result) == 20
+    assert len(responses.calls) == 2
+
+
 large_list_response = {
     "method": responses.GET,
     "url": "http://localhost/api/v4/projects",
